@@ -16,15 +16,10 @@ class SqlConnection(object):
         self.cursor = self.conn.cursor()
 
     def __del__(self):
+        print("del sql")
         self.cursor.close()
         self.conn.close()
 
-    def get_result(self, key):
-        cmd = "SELECT * FROM test_results WHERE test_key='{}'".format(key)
-        self.cursor.execute(cmd)
-        result = self.cursor.fetchone()
-        return result
-
     def execute_sql_command(self, command):
         results = list()
         try:
