@@ -10,7 +10,7 @@ from resources.state_resource import StateResource
 from resources.remote_resource import RemoteResource
 from resources.benchmark_resource import BenchmarkResource
 from resources.oakgate_resource import OakgateResource
-
+from resources.stop_flag_resource import StopFlagResource
 
 class RestClient(object):
 
@@ -22,8 +22,14 @@ class RestClient(object):
         self.remote = RemoteResource(host, port)
         self.benchmark = BenchmarkResource(host, port, __session, time_out)
         self.oakgate = OakgateResource(host, port, __session, time_out)
+        self.stop_flag = StopFlagResource(host, port, __session, time_out)
+
 
 #
 # R = RestClient("172.29.130.138")
-# a = R.oakgate.get_oakgate_device_list()
+# a = R.stop_flag.get_stop_flag()
+# R.stop_flag.set_stop_flag(False)
+# b = R.stop_flag.get_stop_flag()
+# R.stop_flag.set_stop_flag(True)
+# c = R.stop_flag.get_stop_flag()
 # pass
